Learn R Programming

DChaos (version 0.1-3)

infmutua: Estimation of the Average Mutual Information function

Description

This function estimates the Average Mutual Information function considering the argument set selected by the user.

Usage

infmutua(x, partitions = ceiling(1.5 + log(length(x))/log(2)),
  lag.max = 20, doplot = TRUE)

Arguments

x

a numeric vector or time serie.

partitions

a non-negative integer denoting the number of grouping of the set's elements into non-empty subsets, in such a way that every element is included in exactly one subset.

lag.max

a non-negative integer denoting an upper bound for the reconstruction delay (Default 20).

doplot

a logical value denoting if you want to draw a plot TRUE or not FALSE.

Value

The optimum lag which corresponds with the first minimum of the Average Mutual Information function.

References

Fraser, A.M., Swinney, H.L. 1986 Independent coordinates for strange attractors from mutual information. Physical Review A 33(2):1134.

Examples

Run this code
# NOT RUN {
## The first minimum of the average mutual information
## function is showed by simulating a time series from
## the logistic equation.
data<-logistic.ts(u.min=4,u.max=4,B=100,doplot=FALSE)
ts<-data$`Logistic 100`$time.serie
lag.opt<-infmutua(ts,lag.max=10)
show(lag.opt$MutualInf)
show(lag.opt$FirstMin)
# }

Run the code above in your browser using DataLab